@@ -10,12 +10,13 @@
 
 #include <CalendarSupport/FreeBusyItem>
 
-#include <KCalendarCore/FreeBusy>
 #include <KCalendarCore/Attendee>
+#include <KCalendarCore/FreeBusy>
 
 #include <QObject>
 
-namespace IncidenceEditorNG {
+namespace IncidenceEditorNG
+{
 class ConflictResolver;
 }
 
@@ -36,7 +37,8 @@ private Q_SLOTS:
 
 private:
     void insertAttendees();
-    void addAttendee(const QString &email, const KCalendarCore::FreeBusy::Ptr &fb, KCalendarCore::Attendee::Role role = KCalendarCore::Attendee::ReqParticipant);
+    void
+    addAttendee(const QString &email, const KCalendarCore::FreeBusy::Ptr &fb, KCalendarCore::Attendee::Role role = KCalendarCore::Attendee::ReqParticipant);
     QList<CalendarSupport::FreeBusyItem::Ptr> attendees;
     QWidget *parent;
     IncidenceEditorNG::ConflictResolver *resolver;
