@@ -1,39 +1,23 @@
 /*
-  Copyright (c) 2003 Cornelius Schumacher <schumacher@kde.org>
-  Copyright (C) 2005 Reinhold Kainhofer <reinhold@kainhofer.com>
-  Copyright (c) 2005 Rafal Rzepecki <divide@users.sourceforge.net>
-  Copyright (c) 2010 Bertjan Broeksema <broeksema@kde.org>
-  Copyright (C) 2010 Klaralvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
+  SPDX-FileCopyrightText: 2003 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2005 Reinhold Kainhofer <reinhold@kainhofer.com>
+  SPDX-FileCopyrightText: 2005 Rafal Rzepecki <divide@users.sourceforge.net>
+  SPDX-FileCopyrightText: 2010 Bertjan Broeksema <broeksema@kde.org>
+  SPDX-FileCopyrightText: 2010 Klaralvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #include "attachmenteditdialog.h"
 #include "attachmenticonview.h"
 #include "ui_attachmenteditdialog.h"
-#include <KLocalizedString>
 #include <KIO/StoredTransferJob>
 #include <KJobWidgets>
-#include <QLocale>
+#include <KLocalizedString>
 #include <QDialogButtonBox>
-#include <QPushButton>
+#include <QLocale>
 #include <QMimeDatabase>
+#include <QPushButton>
 
 using namespace IncidenceEditorNG;
 
@@ -41,22 +25,21 @@ AttachmentEditDialog::AttachmentEditDialog(AttachmentIconItem *item, QWidget *pa
     : QDialog(parent)
     ,
 #ifdef KDEPIM_ENTERPRISE_BUILD
-    mAttachment(KCalCore::Attachment('\0'))
-    //use the non-uri constructor
-    // as we want inline by default
+    mAttachment(KCalendarCore::Attachment('\0'))
+// use the non-uri constructor
+// as we want inline by default
 #else
-    mAttachment(KCalCore::Attachment(QString()))
+    mAttachment(KCalendarCore::Attachment(QString()))
 #endif
     , mItem(item)
     , mUi(new Ui::AttachmentEditDialog)
 {
-    setWindowTitle(i18n("Edit Attachment"));
+    setWindowTitle(i18nc("@title:window", "Edit Attachment"));
     QMimeDatabase db;
     mMimeType = db.mimeTypeForName(item->mimeType());
     QWidget *page = new QWidget(this);
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(
-        QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
+    auto mainLayout = new QVBoxLayout(this);
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     mOkButton = buttonBox->button(QDialogButtonBox::Ok);
     mOkButton->setDefault(true);
     mOkButton->setShortcut(Qt::CTRL | Qt::Key_Return);
@@ -70,9 +53,7 @@ AttachmentEditDialog::AttachmentEditDialog(AttachmentIconItem *item, QWidget *pa
     mUi->mIcon->setPixmap(item->icon());
     mUi->mInlineCheck->setChecked(item->isBinary());
 
-    const QString typecomment = item->mimeType().isEmpty()
-                                ? i18nc("@label unknown mimetype", "Unknown")
-                                : mMimeType.comment();
+    const QString typecomment = item->mimeType().isEmpty() ? i18nc("@label unknown mimetype", "Unknown") : mMimeType.comment();
     mUi->mTypeLabel->setText(typecomment);
 
     setModal(modal);
@@ -86,16 +67,18 @@ AttachmentEditDialog::AttachmentEditDialog(AttachmentIconItem *item, QWidget *pa
     } else {
         mUi->mInlineCheck->setEnabled(true);
         mUi->mStackedWidget->setCurrentIndex(1);
-        mUi->mSizeLabel->setText(QStringLiteral("%1 (%2)").
-                                 arg(KIO::convertSize(item->attachment().size()),
-                                     QLocale().toString(item->attachment().size())));
+        mUi->mSizeLabel->setText(QStringLiteral("%1 (%2)").arg(KIO::convertSize(item->attachment().size()), QLocale().toString(item->attachment().size())));
     }
 
-    connect(mUi->mInlineCheck, &QCheckBox::stateChanged, this,
-            &AttachmentEditDialog::inlineChanged);
-    connect(mUi->mURLRequester, qOverload<const QUrl &>(&KUrlRequester::urlSelected), this, static_cast<void (AttachmentEditDialog::*)(const QUrl &)>(&AttachmentEditDialog:: urlChanged));
-    connect(mUi->mURLRequester, &KUrlRequester::textChanged, this, static_cast<void (AttachmentEditDialog::*)(const QString &)>(&AttachmentEditDialog::
-                                                                                                                                urlChanged));
+    connect(mUi->mInlineCheck, &QCheckBox::stateChanged, this, &AttachmentEditDialog::inlineChanged);
+    connect(mUi->mURLRequester,
+            qOverload<const QUrl &>(&KUrlRequester::urlSelected),
+            this,
+            static_cast<void (AttachmentEditDialog::*)(const QUrl &)>(&AttachmentEditDialog::urlChanged));
+    connect(mUi->mURLRequester,
+            &KUrlRequester::textChanged,
+            this,
+            static_cast<void (AttachmentEditDialog::*)(const QString &)>(&AttachmentEditDialog::urlChanged));
 }
 
 AttachmentEditDialog::~AttachmentEditDialog()
@@ -160,8 +143,7 @@ void AttachmentEditDialog::slotApply()
 
 void AttachmentEditDialog::inlineChanged(int state)
 {
-    mOkButton->setEnabled(!mUi->mURLRequester->url().toDisplayString().trimmed().isEmpty()
-                          || mUi->mStackedWidget->currentIndex() == 1);
+    mOkButton->setEnabled(!mUi->mURLRequester->url().toDisplayString().trimmed().isEmpty() || mUi->mStackedWidget->currentIndex() == 1);
     if (state == Qt::Unchecked && mUi->mStackedWidget->currentIndex() == 1) {
         mUi->mStackedWidget->setCurrentIndex(0);
         if (!mItem->savedUri().isEmpty()) {
@@ -176,8 +158,7 @@ void AttachmentEditDialog::urlChanged(const QString &url)
 {
     const bool urlIsNotEmpty = !url.trimmed().isEmpty();
     mOkButton->setEnabled(urlIsNotEmpty);
-    mUi->mInlineCheck->setEnabled(urlIsNotEmpty
-                                  || mUi->mStackedWidget->currentIndex() == 1);
+    mUi->mInlineCheck->setEnabled(urlIsNotEmpty || mUi->mStackedWidget->currentIndex() == 1);
 }
 
 void AttachmentEditDialog::urlChanged(const QUrl &url)
