@@ -1,28 +1,15 @@
 /*
-  Copyright (C) 2010 Casey Link <unnamedrambler@gmail.com>
-  Copyright (C) 2009-2010 Klaralvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
+  SPDX-FileCopyrightText: 2010 Casey Link <unnamedrambler@gmail.com>
+  SPDX-FileCopyrightText: 2009-2010 Klaralvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef INCIDENCEEDITOR_ATTENDEELINE_H
 #define INCIDENCEEDITOR_ATTENDEELINE_H
 
-#include <LibkdepimAkonadi/AddresseeLineEdit>
 #include <Libkdepim/MultiplyingLine>
+#include <PimCommonAkonadi/AddresseeLineEdit>
 
 #include <KCalendarCore/Attendee>
 
@@ -31,7 +18,8 @@
 
 class QKeyEvent;
 
-namespace IncidenceEditorNG {
+namespace IncidenceEditorNG
+{
 class AttendeeData;
 
 class AttendeeComboBox : public QToolButton
@@ -61,11 +49,11 @@ protected:
 private:
     void slotActionTriggered();
     QMenu *mMenu = nullptr;
-    QVector<QPair<QString, QIcon> > mList;
-    int mCurrentIndex;
+    QVector<QPair<QString, QIcon>> mList;
+    int mCurrentIndex = -1;
 };
 
-class AttendeeLineEdit : public KPIM::AddresseeLineEdit
+class AttendeeLineEdit : public PimCommon::AddresseeLineEdit
 {
     Q_OBJECT
 public:
@@ -86,13 +74,10 @@ class AttendeeLine : public KPIM::MultiplyingLine
 {
     Q_OBJECT
 public:
-    enum AttendeeActions {
-        EventActions,
-        TodoActions
-    };
+    enum AttendeeActions { EventActions, TodoActions };
 
     explicit AttendeeLine(QWidget *parent);
-    virtual ~AttendeeLine()
+    ~AttendeeLine() override
     {
     }
 
