@@ -11,19 +11,22 @@
 #include <QDateTime>
 #include <QWidget>
 
-namespace KGantt {
+namespace KGantt
+{
 class DateTimeGrid;
 class GraphicsView;
 }
 
-namespace CalendarSupport {
+namespace CalendarSupport
+{
 class FreeBusyItemModel;
 }
 
 class QComboBox;
 class QTreeView;
 
-namespace IncidenceEditorNG {
+namespace IncidenceEditorNG
+{
 class FreeBusyGanttProxyModel;
 class RowController;
 
@@ -32,7 +35,7 @@ class VisualFreeBusyWidget : public QWidget
     Q_OBJECT
 public:
     explicit VisualFreeBusyWidget(CalendarSupport::FreeBusyItemModel *model, int spacing = 8, QWidget *parent = nullptr);
-    ~VisualFreeBusyWidget();
+    ~VisualFreeBusyWidget() override;
 
 public Q_SLOTS:
     void slotUpdateIncidenceStartEnd(const QDateTime &, const QDateTime &);
